
#ifndef _C14_dy660_
#define _C14_dy660_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F354_4217(EIF_REFERENCE);
extern void EIF_Minit660(void);

#ifdef __cplusplus
}
#endif

#endif
